@@ -21,8 +21,12 @@ set -ex
 
 source commons $@
 
+if [ "$PLUGIN" == "spark" ]; then
+    sahara_build_image
+fi
+
 echo "[[local|localrc]]" >> $LOCALCONF_PATH
-echo "IMAGE_URLS=$SAHARA_FAKE_PLUGIN_IMAGE" >> $LOCALCONF_PATH
+echo "IMAGE_URLS=$SAHARA_IMAGE" >> $LOCALCONF_PATH
 
 # Here we can set some configurations for local.conf
 # for example, to pass some config options directly to sahara.conf file
